diff --git a/html/pages/device/edit/ports.inc.php b/html/pages/device/edit/ports.inc.php
index 03eddabb9..aebfe6da4 100644
--- a/html/pages/device/edit/ports.inc.php
+++ b/html/pages/device/edit/ports.inc.php
@@ -29,10 +29,10 @@ while($device = mysql_fetch_array($query)) {
echo("
".$device['ifDescr'] . " | ");
echo("". $device['ifAdminStatus']." | ");
# Mark interfaces which are down yet not ignored, or up - yet ignored - as to draw the attention
# to a possible problem.
#
- $outofsync = ($device['ignore'] == ($device['ifOperStatus'] == 'down' ? 1 : 0)) ? "" : "class=red";
+ $outofsync = ($device['ignore'] == ($device['ifOperStatus'] == 'down' && $device['ifAdminStatus'] != 'down' ? 1 : 0)) ? "" : "class=red";
echo("". $device['ifOperStatus']." | ");
@@ -29,10 +29,10 @@ while($device = mysql_fetch_array($query)) {
".$device['ifDescr'] . " | ");
echo("". $device['ifAdminStatus']." | ");
- # Mark interfaces which are down yet not ignored, or up - yet ignored - as to draw the attention
+ # Mark interfaces which are OperDown (but not AdminDown) yet not ignored, or up - yet ignored - as to draw the attention
# to a possible problem.
#